==> openshift-model-operator-6.6.0-sources.jar: io/fabric8/openshift/api/model/operator/controlplane/v1alpha1/LogEntryFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.controlplane.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LogEntryFluentImpl<A extends LogEntryFluent<A>> extends BaseFluent<A> implements LogEntryFluent<A>{
  public LogEntryFluentImpl() {
  }
  public LogEntryFluentImpl(LogEntry instance) {
    this.withLatency(instance.getLatency()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withSuccess(instance.getSuccess()); 
    this.withTime(instance.getTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Duration latency;
  private String message;
  private String reason;
  private Boolean success;
  private String time;
  private Map<String,Object> additionalProperties;
  public Duration getLatency() {
    return this.latency;
  }
  public A withLatency(Duration latency) {
    this.latency=latency; return (A) this;
  }
  public Boolean hasLatency() {
    return this.latency != null;
  }
  public String getMessage() {
    return this.message;
  }
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  public Boolean hasMessage() {
    return this.message != null;
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public Boolean hasReason() {
    return this.reason != null;
  }
  public Boolean getSuccess() {
    return this.success;
  }
  public A withSuccess(Boolean success) {
    this.success=success; return (A) this;
  }
  public Boolean hasSuccess() {
    return this.success != null;
  }
  public String getTime() {
    return this.time;
  }
  public A withTime(String time) {
    this.time=time; return (A) this;
  }
  public Boolean hasTime() {
    return this.time != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LogEntryFluentImpl that = (LogEntryFluentImpl) o;
    if (latency != null ? !latency.equals(that.latency) :that.latency != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (success != null ? !success.equals(that.success) :that.success != null) return false;
    if (time != null ? !time.equals(that.time) :that.time != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(latency,  message,  reason,  success,  time,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (latency != null) { sb.append("latency:"); sb.append(latency + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (success != null) { sb.append("success:"); sb.append(success + ","); }
    if (time != null) { sb.append("time:"); sb.append(time + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withSuccess() {
    return withSuccess(true);
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/controlplane/v1alpha1/LogEntryFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.controlplane.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LogEntryFluentImpl<A extends LogEntryFluent<A>> extends BaseFluent<A> implements LogEntryFluent<A>{
  public LogEntryFluentImpl() {
  }
  public LogEntryFluentImpl(LogEntry instance) {
    if (instance != null) {
      this.withLatency(instance.getLatency());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withSuccess(instance.getSuccess());
      this.withTime(instance.getTime());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Duration latency;
  private String message;
  private String reason;
  private Boolean success;
  private String time;
  private Map<String,Object> additionalProperties;
  public Duration getLatency() {
    return this.latency;
  }
  public A withLatency(Duration latency) {
    this.latency=latency; return (A) this;
  }
  public Boolean hasLatency() {
    return this.latency != null;
  }
  public String getMessage() {
    return this.message;
  }
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  public Boolean hasMessage() {
    return this.message != null;
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public Boolean hasReason() {
    return this.reason != null;
  }
  public Boolean getSuccess() {
    return this.success;
  }
  public A withSuccess(Boolean success) {
    this.success=success; return (A) this;
  }
  public Boolean hasSuccess() {
    return this.success != null;
  }
  public String getTime() {
    return this.time;
  }
  public A withTime(String time) {
    this.time=time; return (A) this;
  }
  public Boolean hasTime() {
    return this.time != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LogEntryFluentImpl that = (LogEntryFluentImpl) o;
    if (!java.util.Objects.equals(latency, that.latency)) return false;

    if (!java.util.Objects.equals(message, that.message)) return false;

    if (!java.util.Objects.equals(reason, that.reason)) return false;

    if (!java.util.Objects.equals(success, that.success)) return false;

    if (!java.util.Objects.equals(time, that.time)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(latency,  message,  reason,  success,  time,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (latency != null) { sb.append("latency:"); sb.append(latency + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (success != null) { sb.append("success:"); sb.append(success + ","); }
    if (time != null) { sb.append("time:"); sb.append(time + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withSuccess() {
    return withSuccess(true);
  }
  
}
